@@ -13,7 +13,7 @@ import shutil
 def main(config: dict, user_code: callable):
 
 	# Copy original_icon.png to pack.png if it exists
-	if os.path.exists(f"{config['textures_folder']}/original_icon.png"):
+	if os.path.exists(f"{config['assets_folder']}/original_icon.png"):
 		super_copy(f"{config['assets_folder']}/original_icon.png", f"{config['build_resource_pack']}/pack.png")
 		super_copy(f"{config['assets_folder']}/original_icon.png", f"{config['build_datapack']}/pack.png")
 
